@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-object-barchart.c,v 1.2 2001/10/09 03:18:44 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.3 2001/11/20 05:16:39 trow Exp $ */
 
 /*
  * guppi-object-barchart.c
@@ -345,7 +345,7 @@ build_bar_data(GuppiObjectBarchart *obar)
   gint i, j, k = 0;
   /* Convert our data into the appropriate GuppiSeq-derived objects. */
 
-  table = guppi_data_table_new ();
+  table = (GuppiDataTable *) guppi_data_table_new ();
   guppi_data_table_set_dimensions (table, obar->data_rows, obar->data_cols);
   
   for (j = 0; j < obar->data_cols; ++j) {
@@ -865,4 +865,4 @@ guppi_object_barchart_new (void)
 
 
 
-/* $Id: guppi-object-barchart.c,v 1.2 2001/10/09 03:18:44 trow Exp $ */
+/* $Id: guppi-object-barchart.c,v 1.3 2001/11/20 05:16:39 trow Exp $ */
