@@ -1,9 +1,10 @@
-/* $Id: guppi-scatter-state.h,v 1.7 2001/01/16 23:36:04 trow Exp $ */
+/* $Id: guppi-scatter-state.h,v 1.10 2001/11/08 06:13:41 trow Exp $ */
 
 /*
  * guppi-scatter-state.h
  *
- * Copyright (C) 1999 EMC Capital Management, Inc.
+ * Copyright (C) 1999, 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -29,29 +30,27 @@
 
 /* #include <gnome.h> */
 #include <guppi-defs.h>
+#include <guppi-element-state.h>
 #include <guppi-seq-boolean.h>
 #include <guppi-seq-scalar.h>
-#include <guppi-seq-integer.h>
-#include <guppi-element-state.h>
-#include "guppi-scatter-style.h"
+#include <guppi-alpha-template.h>
+#include <guppi-marker.h>
 
 BEGIN_GUPPI_DECLS
 
 typedef struct _GuppiScatterState GuppiScatterState;
 typedef struct _GuppiScatterStateClass GuppiScatterStateClass;
 
-#define GUPPI_SCATTER_STATE_STYLE_COUNT 16
 struct _GuppiScatterState {
   GuppiElementState object;
 
-  GuppiScatterStyle *style[GUPPI_SCATTER_STATE_STYLE_COUNT];
+  GuppiMarker last_marker;
+  double last_size1, last_size2, last_scale;
+  GuppiPixbuf *last_pixbuf;
 };
 
 struct _GuppiScatterStateClass {
   GuppiElementStateClass parent_class;
-
-  /* signal handlers */
-  void (*changed_style) (gint);
 };
 
 #define GUPPI_TYPE_SCATTER_STATE (guppi_scatter_state_get_type())
@@ -69,44 +68,52 @@ GtkType guppi_scatter_state_get_type (void);
 
 GuppiElementState *guppi_scatter_state_new (void);
 
-GuppiSeqScalar *guppi_scatter_state_x_data (GuppiScatterState *);
-GuppiSeqScalar *guppi_scatter_state_y_data (GuppiScatterState *);
-GuppiSeqInteger *guppi_scatter_state_style_data (GuppiScatterState *);
-GuppiSeqScalar *guppi_scatter_state_color_gradient_data (GuppiScatterState *);
-GuppiSeqScalar *guppi_scatter_state_size1_gradient_data (GuppiScatterState *);
-GuppiSeqScalar *guppi_scatter_state_size2_gradient_data (GuppiScatterState *);
+/* convenience functions */
+GuppiSeqScalar  *guppi_scatter_state_get_x_data (GuppiScatterState *);
+GuppiSeqScalar  *guppi_scatter_state_get_y_data (GuppiScatterState *);
+GuppiSeqBoolean *guppi_scatter_state_get_mask_data (GuppiScatterState *);
+GuppiSeqScalar  *guppi_scatter_state_get_color_data (GuppiScatterState *);
+GuppiSeqScalar  *guppi_scatter_state_get_size1_data (GuppiScatterState *);
+GuppiSeqScalar  *guppi_scatter_state_get_size2_data (GuppiScatterState *);
 
-void guppi_scatter_state_set_x_data (GuppiScatterState *, GuppiSeqScalar *);
-void guppi_scatter_state_set_y_data (GuppiScatterState *, GuppiSeqScalar *);
-void guppi_scatter_state_set_style_data (GuppiScatterState *,
-					 GuppiSeqInteger *);
-void guppi_scatter_state_set_color_gradient_data (GuppiScatterState *,
-						  GuppiSeqScalar *);
-void guppi_scatter_state_set_size1_gradient_data (GuppiScatterState *,
-						  GuppiSeqScalar *);
-void guppi_scatter_state_set_size2_gradient_data (GuppiScatterState *,
-						  GuppiSeqScalar *);
+void guppi_scatter_state_set_x_data     (GuppiScatterState *, GuppiSeqScalar *);
+void guppi_scatter_state_set_y_data     (GuppiScatterState *, GuppiSeqScalar *);
+void guppi_scatter_state_set_mask_data  (GuppiScatterState *, GuppiSeqBoolean *);
+void guppi_scatter_state_set_color_data (GuppiScatterState *, GuppiSeqScalar *);
+void guppi_scatter_state_set_size1_data (GuppiScatterState *, GuppiSeqScalar *);
+void guppi_scatter_state_set_size2_data (GuppiScatterState *, GuppiSeqScalar *);
 
-GuppiScatterStyle *guppi_scatter_state_get_style (GuppiScatterState *, gint);
+gboolean guppi_scatter_state_get_point_properties (GuppiScatterState *,
+						   gint index,
+						   gboolean *visible,
+						   GuppiMarker *marker,
+						   guint32 *color,
+						   double *size1,
+						   double *size2);
+
+GuppiPixbuf *guppi_scatter_state_get_point_pixbuf (GuppiScatterState *,
+						   gint index,
+						   double scale_factor,
+						   guint32 *color);
 
 
 gboolean guppi_scatter_state_closest_point (GuppiScatterState *,
 					    double x, double y, double max_r,
 					    double x_scale, double y_scale,
-					    gint * index);
+					    gint *index);
 
 void guppi_scatter_state_brush_rectangle (GuppiScatterState *,
-					  gint brush_number,
 					  double x0, double y0,
-					  double x1, double y1);
+					  double x1, double y1,
+					  gboolean hidden);
 
 void guppi_scatter_state_brush_circle (GuppiScatterState *,
-				       gint brush_number,
 				       double x, double y, double r_pixels,
-				       double x_scale, double y_scale);
+				       double x_scale, double y_scale,
+				       gboolean hidden);
 
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SCATTER-STATE_H */
 
-/* $Id: guppi-scatter-state.h,v 1.7 2001/01/16 23:36:04 trow Exp $ */
+/* $Id: guppi-scatter-state.h,v 1.10 2001/11/08 06:13:41 trow Exp $ */
