@@ -26,10 +26,12 @@
  */
 
 #include <config.h>
+#include "guppi-date-indexed.h"
+
 #include <stdlib.h>
 #include <guppi-convenient.h>
-#include "guppi-date-indexed.h"
-#include "guppi-date-indexed-impl.h"
+#include <guppi-memory.h>
+#include <guppi-i18n.h>
 
 typedef struct _GuppiDateIndexedPrivate GuppiDateIndexedPrivate;
 struct _GuppiDateIndexedPrivate {
@@ -46,30 +48,6 @@ struct _GuppiDateIndexedPrivate {
 
 static GtkObjectClass * parent_class = NULL;
 
-enum {
-  ARG_0
-};
-
-static void
-guppi_date_indexed_get_arg (GtkObject *obj, GtkArg *arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
-static void
-guppi_date_indexed_set_arg (GtkObject *obj, GtkArg *arg, guint arg_id)
-{
-  switch (arg_id) {
-
-  default:
-    break;
-  };
-}
-
 static void
 guppi_date_indexed_finalize (GtkObject *obj)
 {
@@ -86,6 +64,29 @@ guppi_date_indexed_finalize (GtkObject *obj)
     parent_class->finalize (obj);
 }
 
+static gchar *
+get_size_info (GuppiData *d)
+{
+  GuppiDateIndexed *ind = GUPPI_DATE_INDEXED (d);
+  const GDate *dt1, *dt2;
+  gchar dt1buf[32];
+  gchar dt2buf[32];
+
+  if (guppi_date_indexed_empty (ind))
+    return guppi_strdup (_("empty"));
+
+  dt1 = guppi_date_indexed_start (ind);
+  dt2 = guppi_date_indexed_end (ind);
+
+  if (dt1 && dt2 && g_date_valid ((GDate *)dt1) && g_date_valid ((GDate *)dt2)) {
+    g_date_strftime (dt1buf, 32, "%x", (GDate *) dt1);
+    g_date_strftime (dt2buf, 32, "%x", (GDate *) dt2);
+    return guppi_strdup_printf (_("%s to %s"), dt1buf, dt2buf);
+  }
+   
+  return guppi_strdup (_("invalid"));
+}
+
 static void
 changed (GuppiData *data)
 {
@@ -97,22 +98,24 @@ changed (GuppiData *data)
     GUPPI_DATA_CLASS (parent_class)->changed (data);
 }
 
-static xmlNodePtr
-export_xml_content (GuppiData *data, GuppiXMLDocument *doc)
+static void
+export_xml (GuppiData *data, GuppiXMLDocument *doc, xmlNodePtr content_node)
 {
   GuppiDateIndexed *ind = GUPPI_DATE_INDEXED (data);
   GuppiDateIndexedClass *klass;
   GDate dt;
-  xmlNodePtr content_node;
   gchar buf[64];
+  xmlNodePtr days_node;
 
   klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (data)->klass);
 
   if (! klass->export_xml_element) {
-    return xmlNewComment ("XML element format undefined.");
+    xmlAddChild (content_node,  xmlNewComment ("XML element format undefined."));
+    return;
   }
 
-  content_node = xmlNewNode (doc->ns, "Content");
+  days_node = guppi_xml_new_node (doc, "Days");
+  xmlAddChild (content_node, days_node);
 
   dt = *guppi_date_indexed_start (ind);
   while (guppi_date_indexed_in_bounds (ind, &dt)) {
@@ -122,16 +125,14 @@ export_xml_content (GuppiData *data, GuppiXMLDocument *doc)
 		g_date_year ((GDate *)&dt), g_date_month ((GDate *)&dt), g_date_day ((GDate *)&dt));
     xmlNewProp (node, "date", buf);
     if (node)
-      xmlAddChild (content_node, node);
+      xmlAddChild (days_node, node);
       
     guppi_date_indexed_incr (ind, &dt);
   }
-
-  return content_node;
 }
 
-static void
-import_xml_content (GuppiData *data, GuppiXMLDocument *doc, xmlNodePtr node)
+static gboolean
+import_xml (GuppiData *data, GuppiXMLDocument *doc, xmlNodePtr node)
 {
   GuppiDateIndexed *ind = GUPPI_DATE_INDEXED (data);
   GuppiDateIndexedClass *klass;
@@ -139,47 +140,34 @@ import_xml_content (GuppiData *data, GuppiXMLDocument *doc, xmlNodePtr node)
   gchar *buf;
   gint y, m, d;
     
-  g_return_if_fail (!strcmp (node->name, "Content"));
-
   klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (data)->klass);
 
   if (! klass->import_xml_element) {
     g_warning ("XML element reader undefined.");
-    return;
+    return FALSE;
   }
 
-  node = node->xmlChildrenNode;
-  while (node) {
+  if (! strcmp (node->name, "Days")) {
+
+    node = node->xmlChildrenNode;
+    while (node) {
     
-    buf = xmlGetProp (node, "date");
-    if (buf && sscanf (buf, "%d-%d-%d", &y, &m, &d) == 3) {
-      g_date_set_dmy (&dt, d, m, y);
-      klass->import_xml_element (ind, &dt, doc, node);
-      free (buf);
+      buf = xmlGetProp (node, "date");
+      if (buf && sscanf (buf, "%d-%d-%d", &y, &m, &d) == 3) {
+	g_date_set_dmy (&dt, d, m, y);
+	klass->import_xml_element (ind, &dt, doc, node);
+	xmlFree (buf);
+      }
+      node = node->next;
     }
-    node = node->next;
+
+    return TRUE;
   }
-}
 
-static void
-prepare_attributes (GuppiAttributes *ax)
-{
-  if (GUPPI_DATA_CLASS (parent_class)->prepare_attributes)
-    GUPPI_DATA_CLASS (parent_class)->prepare_attributes (ax);
-
-  guppi_attributes_declare_int (ax, "size");
-  guppi_attributes_declare_date (ax, "start_date");
-  guppi_attributes_declare_date (ax, "end_date");
-}
-
-static void
-set_attributes (GuppiData *d, GuppiAttributes *ax)
-{
-  GuppiDateIndexed* ind = GUPPI_DATE_INDEXED (d);
-  
-  guppi_attributes_set_date (ax, "start_date", guppi_date_indexed_start (ind));
-  guppi_attributes_set_date (ax, "end_date",   guppi_date_indexed_end   (ind));
-  guppi_attributes_set_int  (ax, "size",       guppi_date_indexed_size  (ind));
+  if (GUPPI_DATA_CLASS (parent_class)->import_xml)
+    return GUPPI_DATA_CLASS (parent_class)->import_xml (data, doc, node);
+  else
+    return FALSE;
 }
 
 static void
@@ -190,15 +178,13 @@ guppi_date_indexed_class_init (GuppiDateIndexedClass *klass)
 
   parent_class = gtk_type_class(GUPPI_TYPE_DATA);
 
-  object_class->get_arg = guppi_date_indexed_get_arg;
-  object_class->set_arg = guppi_date_indexed_set_arg;
   object_class->finalize = guppi_date_indexed_finalize;
 
-  data_class->changed = changed;
-  data_class->prepare_attributes = prepare_attributes;
-  data_class->set_attributes = set_attributes;
-  data_class->export_xml_content = export_xml_content;
-  data_class->import_xml_content = import_xml_content;
+  data_class->get_size_info = get_size_info;
+
+  data_class->changed    = changed;
+  data_class->export_xml = export_xml;
+  data_class->import_xml = import_xml;
 }
 
 static void
@@ -233,17 +219,15 @@ static void
 get_bounds (GuppiDateIndexed *ind)
 {
   GuppiDateIndexedPrivate *p;
-  GuppiDateIndexedImpl *impl;
-  GuppiDateIndexedImplClass *impl_class;
+  GuppiDateIndexedClass *klass;
   
   p = priv (ind);
 
-  impl = GUPPI_DATE_INDEXED_IMPL (guppi_data_impl (GUPPI_DATA (ind)));
-  impl_class = GUPPI_DATE_INDEXED_IMPL_CLASS (GTK_OBJECT (impl)->klass);
+  klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (ind)->klass);
 
-  g_assert (impl_class->bounds);
+  g_assert (klass->bounds);
 
-  impl_class->bounds (impl, &p->start_date, &p->end_date);
+  klass->bounds (ind, &p->start_date, &p->end_date);
 
   p->have_bounds = TRUE;
 }
@@ -254,7 +238,7 @@ guppi_date_indexed_start (GuppiDateIndexed *ind)
 {
   GuppiDateIndexedPrivate *p;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), NULL);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), NULL);
 
   p = priv (ind);
 
@@ -269,7 +253,7 @@ guppi_date_indexed_end (GuppiDateIndexed *ind)
 {
   GuppiDateIndexedPrivate *p;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), NULL);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), NULL);
 
   p = priv (ind);
 
@@ -290,7 +274,7 @@ guppi_date_indexed_in_bounds (GuppiDateIndexed *ind, const GDate *dt)
 {
   GuppiDateIndexedPrivate *p;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), FALSE);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), FALSE);
   g_return_val_if_fail (dt && g_date_valid ((GDate *) dt), FALSE);
 
   p = priv (ind);
@@ -306,7 +290,7 @@ guppi_date_indexed_clamp (GuppiDateIndexed *ind, GDate *dt)
 {
   GuppiDateIndexedPrivate *p;
 
-  g_return_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind));
+  g_return_if_fail (GUPPI_IS_DATE_INDEXED (ind));
   g_return_if_fail (dt && g_date_valid (dt));
 
   p = priv (ind);
@@ -324,10 +308,9 @@ gboolean
 guppi_date_indexed_valid (GuppiDateIndexed *ind, const GDate *dt)
 {
   GuppiDateIndexedPrivate *p;
-  GuppiDateIndexedImpl *impl;
-  GuppiDateIndexedImplClass *impl_class;
+  GuppiDateIndexedClass *klass;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), FALSE);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), FALSE);
   g_return_val_if_fail (dt && g_date_valid ((GDate *) dt), FALSE);
 
   p = priv (ind);
@@ -338,12 +321,11 @@ guppi_date_indexed_valid (GuppiDateIndexed *ind, const GDate *dt)
   if (OUT_OF_BOUNDS (p, dt))
     return FALSE;
 
-  impl = GUPPI_DATE_INDEXED_IMPL (guppi_data_impl (GUPPI_DATA (ind)));
-  impl_class = GUPPI_DATE_INDEXED_IMPL_CLASS (GTK_OBJECT (impl)->klass);
+  klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (ind)->klass);
 
-  g_assert (impl_class->valid);
+  g_assert (klass->valid);
 
-  return impl_class->valid (impl, dt);
+  return klass->valid (ind, dt);
 }
 
 gboolean
@@ -352,10 +334,9 @@ guppi_date_indexed_step (GuppiDateIndexed *ind, GDate *dt, gint delta)
   GuppiDateIndexedPrivate *p;
   GDate min_stepped_date;
 
-  GuppiDateIndexedImpl *impl;
-  GuppiDateIndexedImplClass *impl_class;
+  GuppiDateIndexedClass *klass;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), FALSE);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), FALSE);
   g_return_val_if_fail (dt != NULL && g_date_valid (dt), FALSE);
   
   if (delta == 0)
@@ -378,21 +359,19 @@ guppi_date_indexed_step (GuppiDateIndexed *ind, GDate *dt, gint delta)
     return FALSE;
   }
       
+  klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT(ind)->klass);
 
-  impl = GUPPI_DATE_INDEXED_IMPL (guppi_data_impl (GUPPI_DATA (ind)));
-  impl_class = GUPPI_DATE_INDEXED_IMPL_CLASS (GTK_OBJECT(impl)->klass);
-
-  if (impl_class->step) {
+  if (klass->step) {
     GDate base_dt = *dt;
     
-    return impl_class->step (impl, &base_dt, delta, dt);
+    return klass->step (ind, &base_dt, delta, dt);
 
   } else {
 
     /* Walk through the dates, decrementing delta every time we pass over
        a valid date. */
 
-    g_assert (impl_class->valid);
+    g_assert (klass->valid);
 
     while (delta) {
 
@@ -406,7 +385,7 @@ guppi_date_indexed_step (GuppiDateIndexed *ind, GDate *dt, gint delta)
 	  return FALSE;
       }
 
-      if (impl_class->valid (impl, dt)) 
+      if (klass->valid (ind, dt)) 
 	delta += (delta > 0) ? -1 : +1;
     }
   }
@@ -431,7 +410,7 @@ guppi_date_indexed_size (GuppiDateIndexed *ind)
 {
   GuppiDateIndexedPrivate *p;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), -1);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), -1);
 
   if (guppi_date_indexed_empty (ind))
     return 0;
@@ -439,15 +418,13 @@ guppi_date_indexed_size (GuppiDateIndexed *ind)
   p = priv (ind);
 
   if (! p->have_size) {
-    GuppiDateIndexedImpl *impl;
-    GuppiDateIndexedImplClass *impl_class;
+    GuppiDateIndexedClass *klass;
 
-    impl = GUPPI_DATE_INDEXED_IMPL (guppi_data_impl (GUPPI_DATA(ind)));
-    impl_class = GUPPI_DATE_INDEXED_IMPL_CLASS (GTK_OBJECT (impl)->klass);
+    klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (ind)->klass);
 
-    if (impl_class->size) {
+    if (klass->size) {
 
-      p->size = impl_class->size (impl);
+      p->size = klass->size (ind);
 
     } else {
 
@@ -456,7 +433,7 @@ guppi_date_indexed_size (GuppiDateIndexed *ind)
 
       GDate dt;
 
-      g_assert (impl_class->valid);
+      g_assert (klass->valid);
 
       if (! p->have_bounds)
 	get_bounds (ind);
@@ -468,7 +445,7 @@ guppi_date_indexed_size (GuppiDateIndexed *ind)
       if (g_date_valid (&dt)) {
 	while (IN_UPPER_BOUND (p, &dt)) {
 	
-	  if (impl_class->valid (impl, &dt))
+	  if (klass->valid (ind, &dt))
 	    ++p->size;
 
 	  g_date_add_days (&dt, 1);
@@ -489,7 +466,7 @@ guppi_date_indexed_empty (GuppiDateIndexed *ind)
 {
   gboolean sv, ev;
 
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), TRUE);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), TRUE);
 
   sv = g_date_valid ((GDate *) guppi_date_indexed_start (ind));
   ev = g_date_valid ((GDate *) guppi_date_indexed_end (ind));
@@ -507,30 +484,27 @@ guppi_date_indexed_empty (GuppiDateIndexed *ind)
 gboolean
 guppi_date_indexed_nonempty (GuppiDateIndexed *ind)
 {
-  g_return_val_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind), FALSE);
+  g_return_val_if_fail (GUPPI_IS_DATE_INDEXED (ind), FALSE);
 
   return !guppi_date_indexed_empty (ind);
 }
 
 void
-guppi_date_indexed_bounds_hint (GuppiDateIndexed *ind, 
-				const GDate *start, const GDate *end)
+guppi_date_indexed_bounds_hint (GuppiDateIndexed *ind, const GDate *start, const GDate *end)
 {
-  GuppiDateIndexedImpl *impl;
-  GuppiDateIndexedImplClass *impl_class;
+  GuppiDateIndexedClass *klass;
   
-  g_return_if_fail (ind && GUPPI_IS_DATE_INDEXED (ind));
+  g_return_if_fail (GUPPI_IS_DATE_INDEXED (ind));
   g_return_if_fail (start && g_date_valid ((GDate *)start));
   g_return_if_fail (end && g_date_valid ((GDate *)end));
 
   if (g_date_compare ((GDate *)start, (GDate *)end) > 0)
     return;
 
-  impl = GUPPI_DATE_INDEXED_IMPL (guppi_data_impl (GUPPI_DATA (ind)));
-  impl_class = GUPPI_DATE_INDEXED_IMPL_CLASS (GTK_OBJECT (impl)->klass);
+  klass = GUPPI_DATE_INDEXED_CLASS (GTK_OBJECT (ind)->klass);
 
-  if (impl_class->bounds_hint) 
-    impl_class->bounds_hint (impl, start, end);
+  if (klass->bounds_hint) 
+    klass->bounds_hint (ind, start, end);
  
 }
 
