@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-date.h,v 1.8 2001/01/16 23:36:18 trow Exp $ */
+/* $Id: guppi-seq-date.h,v 1.11 2001/11/19 05:40:40 trow Exp $ */
 
 /*
  * guppi-seq-date.h
@@ -32,7 +32,7 @@
 
 #include "guppi-seq.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -45,6 +45,14 @@ struct _GuppiSeqDate {
 
 struct _GuppiSeqDateClass {
   GuppiSeqClass parent_class;
+
+  /* virtual functions */
+  GDate *(*get)    (GuppiSeqDate *, gint);
+  void   (*set)    (GuppiSeqDate *, gint, GDate *);
+  void   (*insert) (GuppiSeqDate *, gint, GDate *);
+  GDate *(*min)    (GuppiSeqDate *);
+  GDate *(*max)    (GuppiSeqDate *);
+  gint   (*lookup) (GuppiSeqDate *, GDate *);
 };
 
 #define GUPPI_TYPE_SEQ_DATE (guppi_seq_date_get_type())
@@ -75,4 +83,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_DATE_H */
 
-/* $Id: guppi-seq-date.h,v 1.8 2001/01/16 23:36:18 trow Exp $ */
+/* $Id: guppi-seq-date.h,v 1.11 2001/11/19 05:40:40 trow Exp $ */
