@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-integer.h,v 1.7 2001/01/16 23:36:20 trow Exp $ */
+/* $Id: guppi-seq-integer.h,v 1.10 2001/11/19 05:40:40 trow Exp $ */
 
 /*
  * guppi-seq-integer.h
@@ -30,9 +30,9 @@
 
 /* #include <gtk/gtk.h> */
 
-#include <guppi-seq.h>
+#include  "guppi-seq.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -45,6 +45,12 @@ struct _GuppiSeqInteger {
 
 struct _GuppiSeqIntegerClass {
   GuppiSeqClass parent_class;
+
+  void (*range)     (GuppiSeqInteger *, gint *min, gint *max);
+  gint (*frequency) (GuppiSeqInteger *, gint);
+  gint (*get)       (GuppiSeqInteger *, gint);
+  void (*set)       (GuppiSeqInteger *, gint i, gint val);
+  void (*insert)    (GuppiSeqInteger *, gint i, const gint *ptr, gsize N);
 };
 
 #define GUPPI_TYPE_SEQ_INTEGER (guppi_seq_integer_get_type())
@@ -60,17 +66,14 @@ GtkType guppi_seq_integer_get_type (void);
 GuppiData *guppi_seq_integer_new (void);
 
 gint guppi_seq_integer_get (const GuppiSeqInteger *, gint);
-void guppi_seq_integer_get_many (const GuppiSeqInteger *, gint first,
-				 gint last, gint * dest);
+void guppi_seq_integer_get_many (const GuppiSeqInteger *, gint first, gint last, gint * dest);
 
 void guppi_seq_integer_set (GuppiSeqInteger *, gint i, gint val);
-void guppi_seq_integer_set_many_dup (GuppiSeqInteger *, gint i0, gint i1,
-				     gint val);
+void guppi_seq_integer_set_many_dup (GuppiSeqInteger *, gint i0, gint i1, gint val);
 void guppi_seq_integer_set_all (GuppiSeqInteger *, gint val);
 
 void guppi_seq_integer_prepend (GuppiSeqInteger *, gint);
-void guppi_seq_integer_prepend_many (GuppiSeqInteger *, const gint *,
-				     gsize N);
+void guppi_seq_integer_prepend_many (GuppiSeqInteger *, const gint *, gsize N);
 
 void guppi_seq_integer_append (GuppiSeqInteger *, gint);
 void guppi_seq_integer_append_many (GuppiSeqInteger *, const gint *, gsize N);
@@ -89,4 +92,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_INTEGER_H */
 
-/* $Id: guppi-seq-integer.h,v 1.7 2001/01/16 23:36:20 trow Exp $ */
+/* $Id: guppi-seq-integer.h,v 1.10 2001/11/19 05:40:40 trow Exp $ */
