@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-object.h,v 1.5 2001/01/16 23:36:20 trow Exp $ */
+/* $Id: guppi-seq-object.h,v 1.8 2001/11/19 05:40:40 trow Exp $ */
 
 /*
  * guppi-seq-object.h
@@ -29,9 +29,9 @@
 #define _INC_GUPPI_SEQ_OBJECT_H
 
 /* #include <gtk/gtk.h> */
-#include <guppi-seq.h>
+#include  "guppi-seq.h"
 
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -44,6 +44,13 @@ struct _GuppiSeqObject {
 
 struct _GuppiSeqObjectClass {
   GuppiSeqClass parent_class;
+
+  /* Virtual functions */
+
+  GtkObject *(*get)         (GuppiSeqObject *, gint);
+  void       (*set)         (GuppiSeqObject *, gint, GtkObject *);
+  void       (*insert)      (GuppiSeqObject *, gint, GtkObject *);
+  void       (*insert_NULL) (GuppiSeqObject *, gint, gsize);
 };
 
 #define GUPPI_TYPE_SEQ_OBJECT (guppi_seq_object_get_type())
@@ -75,4 +82,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_SEQ_OBJECT_H */
 
-/* $Id: guppi-seq-object.h,v 1.5 2001/01/16 23:36:20 trow Exp $ */
+/* $Id: guppi-seq-object.h,v 1.8 2001/11/19 05:40:40 trow Exp $ */
