@@ -1,6 +1,6 @@
 
 /* This is -*- C -*- */
-/* $Id: guppi-axis-markers.c,v 1.19 2001/10/15 20:58:41 trow Exp $ */
+/* $Id: guppi-axis-markers.c,v 1.20 2001/11/19 05:40:44 trow Exp $ */
 
 /*
  * guppi-axis-markers.c
@@ -412,6 +412,11 @@ guppi_axis_markers_populate_scalar_log (GuppiAxisMarkers * gam,
   g_return_if_fail (goal > 0);
   g_return_if_fail (base > 0);
 
+  if (max / min < base) {
+    guppi_axis_markers_populate_scalar (gam, min, max, goal, base, FALSE);
+    return;
+  }
+
   guppi_axis_markers_freeze (gam);
   guppi_axis_markers_clear (gam);
 
@@ -540,24 +545,30 @@ static void
 populate_dates_quarterly (GuppiAxisMarkers *gam,
 			  GDate *min, GDate *max)
 {
-  gchar buf[32];
-  GDate dt;
-  gint j;
+  gchar monthname[32], buf[32];
+  GDate dt, dt2;
+  gint j, j2;
 
   g_date_set_dmy (&dt, 1, g_date_month (min), g_date_year (min));
 
   while (g_date_lteq (&dt, max)) {
 
+    dt2 = dt;
+    g_date_add_months (&dt2, 1);
     j = g_date_julian (&dt);
+    j2 = g_date_julian (&dt2);
 
-    if (g_date_month (&dt) % 4 == 1) {
-      g_date_strftime (buf, 32, "%d %b %y", &dt);
-      guppi_axis_markers_add (gam, j, GUPPI_TICK_MAJOR, buf);
-    } else {
-      guppi_axis_markers_add (gam, j, GUPPI_TICK_MICRO, "");
-    }
+    g_date_strftime (monthname, 32, "%b", &dt);
+    g_snprintf (buf, 32, "%c-%02d", *monthname, g_date_year (&dt) % 100);
 
-    g_date_add_months (&dt, 1);    
+    if (g_date_month (&dt) % 3 == 1)
+      guppi_axis_markers_add (gam, j, GUPPI_TICK_MAJOR, "");
+    else
+      guppi_axis_markers_add (gam, j, GUPPI_TICK_MINOR, "");
+
+    guppi_axis_markers_add (gam, (j+j2)/2.0, GUPPI_TICK_NONE, buf);
+
+    dt = dt2;
   }
 
 }
@@ -568,24 +579,48 @@ populate_dates_yearly (GuppiAxisMarkers *gam,
 {
   gchar buf[32];
   GDate dt, dt2;
-  gint j,j2;
+  gint j, j2, y;
+  gint count = 0, step = 1;
+  gboolean two_digit_years;
 
   g_date_set_dmy (&dt, 1, 1, g_date_year (min));
+  while (g_date_lteq (&dt, max)) {
+    g_date_add_years (&dt, 1);
+    ++count;
+  }
 
+  two_digit_years = count > 5;
+  if (count > 10)
+    step = 2;
+  if (count > 20)
+    step = 5;
+
+  g_date_set_dmy (&dt, 1, 1, g_date_year (min));
   while (g_date_lteq (&dt, max)) {
     dt2 = dt;
     g_date_add_years (&dt2, 1);
     j = g_date_julian (&dt);
     j2 = g_date_julian (&dt2);
+    y = g_date_year (&dt);
 
-    g_date_strftime (buf, 32, "%Y", &dt);
+    if (two_digit_years) {
+      if (step == 1 || y % step == 0)
+	g_snprintf (buf, 32, "%02d", y % 100);
+      else
+	*buf = '\0';
+    } else {
+      g_snprintf (buf, 32, "%d", y);
+    }
     
     guppi_axis_markers_add (gam, j, GUPPI_TICK_MAJOR, "");
-    guppi_axis_markers_add (gam, (j+j2)/2.0, GUPPI_TICK_NONE, buf);
+    if (*buf)
+      guppi_axis_markers_add (gam, (j+j2)/2.0, GUPPI_TICK_NONE, buf);
 
-    guppi_axis_markers_add (gam, j+0.25*(j2-j), GUPPI_TICK_MICRO, "");
-    guppi_axis_markers_add (gam, (j+j2)/2.0, GUPPI_TICK_MICRO, "");
-    guppi_axis_markers_add (gam, j+0.75*(j2-j), GUPPI_TICK_MICRO, "");
+    if (step == 1) {
+      guppi_axis_markers_add (gam, j+0.25*(j2-j), GUPPI_TICK_MICRO, "");
+      guppi_axis_markers_add (gam, (j+j2)/2.0, GUPPI_TICK_MICRO, "");
+      guppi_axis_markers_add (gam, j+0.75*(j2-j), GUPPI_TICK_MICRO, "");
+    }
     
     dt = dt2;
   }
@@ -612,7 +647,7 @@ guppi_axis_markers_populate_dates (GuppiAxisMarkers *gam,
     populate_dates_weekly (gam, min, max);
   else if (jspan < 8*30)
     populate_dates_monthly (gam, min, max);
-  else if (jspan < 7*90)
+  else if (jspan < 6*90)
     populate_dates_quarterly (gam, min, max); 
   else
     populate_dates_yearly (gam, min, max);
@@ -721,4 +756,4 @@ guppi_axis_markers_max_label_size (GuppiAxisMarkers * gam, GnomeFont * f,
 }
 
 
-/* $Id: guppi-axis-markers.c,v 1.19 2001/10/15 20:58:41 trow Exp $ */
+/* $Id: guppi-axis-markers.c,v 1.20 2001/11/19 05:40:44 trow Exp $ */
