@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.c,v 1.35 2001/05/06 08:26:42 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.42 2001/11/16 16:58:56 trow Exp $ */
 
 /*
  * guppi-element-canvas-item.c
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -26,18 +27,21 @@
  */
 
 #include <config.h>
+#include "guppi-canvas-item.h"
+
 #include <math.h>
 
 #include <libgnomeui/gnome-canvas.h>
 #include <libgnomeui/gnome-canvas-util.h>
 
-#include <guppi-useful.h>
+#include <guppi-debug.h>
+#include <guppi-convenient.h>
+#include <guppi-memory.h>
 #include <guppi-unique-id.h>
 #include "guppi-element-view.h"
-#include "guppi-canvas-item.h"
+
 #include "guppi-basic-tools.h"
 
-typedef struct _GuppiCanvasItemPrivate GuppiCanvasItemPrivate;
 struct _GuppiCanvasItemPrivate {
 
   guppi_uniq_t id;
@@ -48,17 +52,15 @@ struct _GuppiCanvasItemPrivate {
   /* We keep both the state and the view, so we save an occasional
      function call. */
   GuppiElementState *state;
+  guint state_changed_handler;
+
   GuppiElementView *view;
+  guint view_changed_handler;
 
   gboolean clip_buf;
 
-  void (*position_handler) (GuppiCanvasItem *, gpointer);
-  gpointer position_handler_data;
-  guint position_handler_id;
-
   double scale_factor;
 
-  gboolean ready_flag;
   gint realize_idle;
 
   gboolean disable_local_tools;
@@ -67,12 +69,14 @@ struct _GuppiCanvasItemPrivate {
   GuppiPlotToolkit *item_toolkit;
 };
 
-#define priv(x) ((GuppiCanvasItemPrivate*)((x)->opaque_internals))
+#define priv(x) ((x)->priv)
 
 static GtkObjectClass *parent_class = NULL;
 
 enum {
   CHANGED_SCALE,
+  CHANGED_STATE,
+  CHANGED_VIEW,
   LAST_SIGNAL
 };
 
@@ -80,30 +84,23 @@ guint item_signals[LAST_SIGNAL] = { 0 };
 
 
 static void
-guppi_canvas_item_finalize (GtkObject * obj)
+guppi_canvas_item_finalize (GtkObject *obj)
 {
   GuppiCanvasItem *item = GUPPI_CANVAS_ITEM (obj);
   GuppiCanvasItemPrivate *p = priv (item);
-  GuppiGeometry *geom = guppi_element_view_geometry (p->view);
-  GuppiElementState *state = guppi_canvas_item_state (item);
 
   guppi_finalized (obj);
 
   if (p->view) {
-
-    /* Disconnect our "changed" signals. */
-    gtk_signal_disconnect_by_data (GTK_OBJECT (p->view), item);
-    gtk_signal_disconnect_by_data (GTK_OBJECT (state), item);
+    gtk_signal_disconnect (GTK_OBJECT (p->view), p->view_changed_handler);
+    guppi_unref (p->view);
   }
-
-  if (p->position_handler_id) {
-    gtk_signal_disconnect (GTK_OBJECT (geom), p->position_handler_id);
-    p->position_handler_id = 0;
+  
+  if (p->state) {
+    gtk_signal_disconnect (GTK_OBJECT (p->state), p->state_changed_handler);
+    guppi_unref (p->state);
   }
-
-  guppi_unref0 (p->view);
-  guppi_unref0 (p->state);
-
+  
   if (p->realize_idle) {
     gtk_idle_remove (p->realize_idle);
     p->realize_idle = 0;
@@ -111,8 +108,7 @@ guppi_canvas_item_finalize (GtkObject * obj)
 
   guppi_unref0 (p->item_toolkit);
 
-  guppi_free (item->opaque_internals);
-  item->opaque_internals = NULL;
+  guppi_free0 (item->priv);
 
   if (parent_class->finalize)
     parent_class->finalize (obj);
@@ -123,24 +119,22 @@ guppi_canvas_item_finalize (GtkObject * obj)
 static gint
 post_realize_idle_fn (gpointer ptr)
 {
-  GuppiCanvasItem *item;
+  GuppiCanvasItem *item = GUPPI_CANVAS_ITEM (ptr);
   GuppiCanvasItemClass *klass;
 
-  item = GUPPI_CANVAS_ITEM (ptr);
-  if (!guppi_canvas_item_ready (item))
-    return TRUE;
+  if (priv (item)->view != NULL) {
+    klass = GUPPI_CANVAS_ITEM_CLASS (GTK_OBJECT (item)->klass);
+    g_assert (klass->post_realization_init);
+    klass->post_realization_init (item);
+    priv (item)->realize_idle = 0;
+    return FALSE;
+  }
 
-  klass = GUPPI_CANVAS_ITEM_CLASS (GTK_OBJECT (item)->klass);
-  g_assert (klass->post_realization_init);
-  klass->post_realization_init (item);
-
-  priv (item)->realize_idle = 0;
-
-  return FALSE;
+  return TRUE;
 }
 
 static void
-realize (GnomeCanvasItem * gnoitem)
+realize (GnomeCanvasItem *gnoitem)
 {
   GuppiCanvasItem *item = GUPPI_CANVAS_ITEM (gnoitem);
   GuppiCanvasItemClass *klass;
@@ -149,14 +143,13 @@ realize (GnomeCanvasItem * gnoitem)
   if (GNOME_CANVAS_ITEM_CLASS (parent_class)->realize)
     GNOME_CANVAS_ITEM_CLASS (parent_class)->realize (gnoitem);
 
-  /* If our object isn't fully initialized yet, set up an idle function
-     to take care of the post-realization init later. */
   klass = GUPPI_CANVAS_ITEM_CLASS (GTK_OBJECT (gnoitem)->klass);
   if (klass->post_realization_init) {
-    if (guppi_canvas_item_ready (item))
+    if (priv (item)->view != NULL) {
       klass->post_realization_init (item);
-    else
+    } else {
       priv (item)->realize_idle = gtk_idle_add (post_realize_idle_fn, item);
+    }
   }
 }
 
@@ -205,7 +198,7 @@ update (GnomeCanvasItem *item, double aff[6], ArtSVP *clip_path, gint flags)
 }
 
 static void
-render (GnomeCanvasItem * item, GnomeCanvasBuf * in_buf)
+render (GnomeCanvasItem *item, GnomeCanvasBuf *in_buf)
 {
   GuppiCanvasItem *gec;
   GuppiCanvasItemPrivate *p;
@@ -231,7 +224,6 @@ render (GnomeCanvasItem * item, GnomeCanvasBuf * in_buf)
     return;
   }
 
-
   /* Do the right thing if we are the first to draw on the canvas. */
   if (in_buf->is_bg) {
     gnome_canvas_buf_ensure_buf (in_buf);
@@ -289,8 +281,8 @@ render (GnomeCanvasItem * item, GnomeCanvasBuf * in_buf)
 }
 
 static double
-point (GnomeCanvasItem * gci, double x, double y, gint cx, gint cy,
-       GnomeCanvasItem ** actual_item)
+point (GnomeCanvasItem *gci, double x, double y, gint cx, gint cy,
+       GnomeCanvasItem **actual_item)
 {
   double dist;
 
@@ -311,7 +303,37 @@ foreach (GuppiCanvasItem *item, GuppiCanvasItemFunc fn, gpointer ptr)
 }
 
 static void
-guppi_canvas_item_class_init (GuppiCanvasItemClass * klass)
+changed_scale (GuppiCanvasItem *item, double scale)
+{
+  guppi_canvas_item_request_update (item);
+}
+
+static void
+changed_state (GuppiCanvasItem *item)
+{
+  guppi_canvas_item_request_update (item);
+}
+
+static void
+changed_view (GuppiCanvasItem *item)
+{
+  guppi_canvas_item_request_update (item);
+}
+
+typedef void (*GuppiSignal_NONE__DOUBLE) (GtkObject *, double, gpointer user_data);
+
+static void
+guppi_marshal_NONE__DOUBLE (GtkObject *object, GtkSignalFunc func, gpointer func_data, GtkArg *args)
+{
+  GuppiSignal_NONE__DOUBLE rfunc;
+
+  rfunc = (GuppiSignal_NONE__DOUBLE) func;
+  
+  (*rfunc) (object, GTK_VALUE_DOUBLE (args[0]), func_data);
+}
+
+static void
+guppi_canvas_item_class_init (GuppiCanvasItemClass *klass)
 {
   GtkObjectClass *object_class = (GtkObjectClass *) klass;
   GnomeCanvasItemClass *item_class = GNOME_CANVAS_ITEM_CLASS (klass);
@@ -321,30 +343,47 @@ guppi_canvas_item_class_init (GuppiCanvasItemClass * klass)
   object_class->finalize = guppi_canvas_item_finalize;
 
   item_class->realize = realize;
-  item_class->update = update;
-  item_class->render = render;
-  item_class->point = point;
+  item_class->update  = update;
+  item_class->render  = render;
+  item_class->point   = point;
 
-  klass->foreach = foreach;
+  klass->foreach       = foreach;
+  klass->changed_scale = changed_scale;
+  klass->changed_state = changed_state;
+  klass->changed_view  = changed_view;
 
   item_signals[CHANGED_SCALE] =
     gtk_signal_new ("changed_scale",
 		    GTK_RUN_FIRST,
 		    object_class->type,
-		    GTK_SIGNAL_OFFSET (GuppiCanvasItemClass,
-				       changed_scale),
-		    gtk_marshal_NONE__NONE, GTK_TYPE_NONE, 0);
+		    GTK_SIGNAL_OFFSET (GuppiCanvasItemClass, changed_scale),
+		    guppi_marshal_NONE__DOUBLE,
+		    GTK_TYPE_NONE, 1, GTK_TYPE_DOUBLE);
+  
+  item_signals[CHANGED_STATE] =
+    gtk_signal_new ("changed_state",
+		    GTK_RUN_FIRST,
+		    object_class->type,
+		    GTK_SIGNAL_OFFSET (GuppiCanvasItemClass, changed_state),
+		    gtk_marshal_NONE__NONE,
+		    GTK_TYPE_NONE, 0, GTK_TYPE_NONE);
+
+  item_signals[CHANGED_VIEW] =
+    gtk_signal_new ("changed_view",
+		    GTK_RUN_FIRST,
+		    object_class->type,
+		    GTK_SIGNAL_OFFSET (GuppiCanvasItemClass, changed_view),
+		    gtk_marshal_NONE__NONE,
+		    GTK_TYPE_NONE, 0, GTK_TYPE_NONE);
 
   gtk_object_class_add_signals (object_class, item_signals, LAST_SIGNAL);
-
 }
 
 static void
-guppi_canvas_item_init (GuppiCanvasItem * obj)
+guppi_canvas_item_init (GuppiCanvasItem *obj)
 {
   GuppiCanvasItemPrivate *p;
-  p = guppi_new0 (GuppiCanvasItemPrivate, 1);
-  obj->opaque_internals = p;
+  obj->priv = p = guppi_new0 (GuppiCanvasItemPrivate, 1);
 
   p->id = guppi_unique_id ();
 
@@ -434,7 +473,7 @@ guppi_canvas_item_scale (GuppiCanvasItem *item)
  * Returns the item's current geometry.
  **/
 GuppiGeometry *
-guppi_canvas_item_geometry (GuppiCanvasItem * item)
+guppi_canvas_item_geometry (GuppiCanvasItem *item)
 {
   g_return_val_if_fail (item && GUPPI_IS_CANVAS_ITEM (item), FALSE);
   return guppi_element_view_geometry (priv (item)->view);
@@ -448,7 +487,8 @@ guppi_canvas_item_geometry (GuppiCanvasItem * item)
  * and %FALSE otherwise.
  *
  **/
-gboolean guppi_canvas_item_positioned (GuppiCanvasItem * item)
+gboolean
+guppi_canvas_item_positioned (GuppiCanvasItem *item)
 {
   GuppiGeometry *geom;
   g_return_val_if_fail (item && GUPPI_IS_CANVAS_ITEM (item), FALSE);
@@ -457,13 +497,15 @@ gboolean guppi_canvas_item_positioned (GuppiCanvasItem * item)
 }
 
 static void
-pos_cb (GuppiGeometry * geom, GuppiCanvasItem * item)
+state_changed_cb (GuppiElementState *state, gpointer item)
 {
-  GuppiCanvasItemPrivate *p = priv (item);
-  GUPPI_ENTER_MESSAGE (gtk_type_name (GTK_OBJECT_TYPE (item)));
-  if (p->position_handler)
-    p->position_handler (item, p->position_handler_data);
-  GUPPI_EXIT;
+  gtk_signal_emit (GTK_OBJECT (item), item_signals[CHANGED_STATE]);
+}
+
+static void
+view_changed_cb (GuppiElementView *view, gpointer item)
+{
+  gtk_signal_emit (GTK_OBJECT (item), item_signals[CHANGED_VIEW]);
 }
 
 /**
@@ -478,32 +520,30 @@ pos_cb (GuppiGeometry * geom, GuppiCanvasItem * item)
  *
  */
 void
-guppi_canvas_item_set_view (GuppiCanvasItem * item, GuppiElementView * view)
+guppi_canvas_item_set_view (GuppiCanvasItem *item, GuppiElementView *view)
 {
   GuppiCanvasItemPrivate *p;
-  GuppiGeometry *geom;
 
-  g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
+  g_return_if_fail (GUPPI_IS_CANVAS_ITEM (item));
+  g_return_if_fail (GUPPI_IS_ELEMENT_VIEW (view));
+
   p = priv (item);
-
-  if (p->view == view)
-    return;
-
   g_return_if_fail (p->view == NULL);
 
-  g_return_if_fail (view != NULL && GUPPI_IS_ELEMENT_VIEW (view));
-
   p->view = view;
   p->state = guppi_element_view_state (view);
 
   guppi_ref (p->view);
   guppi_ref (p->state);
 
-  geom = guppi_element_view_geometry (view);
-  p->position_handler_id = gtk_signal_connect (GTK_OBJECT (geom),
-					       "changed_position",
-					       GTK_SIGNAL_FUNC (pos_cb),
-					       item);
+  p->state_changed_handler = gtk_signal_connect (GTK_OBJECT (p->state),
+						 "changed",
+						 GTK_SIGNAL_FUNC (state_changed_cb),
+						 item);
+  p->view_changed_handler = gtk_signal_connect (GTK_OBJECT (p->view),
+						"changed",
+						GTK_SIGNAL_FUNC (view_changed_cb),
+						item);
 }
 
 /**
@@ -516,7 +556,7 @@ guppi_canvas_item_set_view (GuppiCanvasItem * item, GuppiElementView * view)
  *
  **/
 void
-guppi_canvas_item_set_scale (GuppiCanvasItem * item, double s)
+guppi_canvas_item_set_scale (GuppiCanvasItem *item, double s)
 {
   GuppiCanvasItemClass *klass;
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -526,68 +566,11 @@ guppi_canvas_item_set_scale (GuppiCanvasItem * item, double s)
 
   if (priv (item)->scale_factor != s) {
     priv (item)->scale_factor = s;
-    if (klass->set_scale)
-      klass->set_scale (item);
+    gtk_signal_emit (GTK_OBJECT (item), item_signals[CHANGED_SCALE], s);
     guppi_canvas_item_request_update (item);
-    gtk_signal_emit (GTK_OBJECT (item), item_signals[CHANGED_SCALE]);
   }
 }
 
-/**
- * guppi_canvas_item_ready
- * @item: the canvas item
- *
- * Returns TRUE if the item is ready to be displayed, and FALSE otherwise.
- **/
-gboolean
-guppi_canvas_item_ready (GuppiCanvasItem * item)
-{
-  g_return_val_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item), FALSE);
-
-  return priv (item)->ready_flag;
-}
-
-/**
- * guppi_canvas_item_set_ready
- * @item: the canvas item
- *
- * Sets the item's ready flag, indicating that it is ready to be displayed.
- * It is an error to call this function on any #GuppiCanvasItem more
- * than once.
- *
- **/
-void
-guppi_canvas_item_set_ready (GuppiCanvasItem * item)
-{
-  g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
-  g_assert (!priv (item)->ready_flag);
-  priv (item)->ready_flag = TRUE;
-}
-
-/**
- * guppi_canvas_item_set_position_handler
- * @item: the canvas item
- * @func: a callback function
- * @user_data: a pointer passed to the callback function
- *
- * Attach a callback function to the item that is invoked every time
- * the item is determined to have changed position.
- *
- */
-void
-guppi_canvas_item_set_position_handler (GuppiCanvasItem * item,
-					void (*fn) (GuppiCanvasItem *,
-						    gpointer),
-					gpointer user_data)
-{
-  GuppiCanvasItemPrivate *p;
-  g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
-  p = priv (item);
-  p->position_handler = fn;
-  p->position_handler_data = user_data;
-}
-
-
 /***************************************************************************/
 
 /**
@@ -604,6 +587,7 @@ void
 guppi_canvas_item_set_bbox_c (GuppiCanvasItem *item,
 			      gint cx0, gint cy0, gint cx1, gint cy1)
 {
+  GuppiCanvasItemClass *klass;
   GuppiCanvasItemPrivate *p;
 
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -614,12 +598,19 @@ guppi_canvas_item_set_bbox_c (GuppiCanvasItem *item,
 
   if (p->cx0 != cx0 || p->cy0 != cy0 || p->cx1 != cx1 || p->cy1 != cy1) {
 
+    klass = GUPPI_CANVAS_ITEM_CLASS (GTK_OBJECT (item)->klass);
+
     p->cx0 = cx0;
     p->cx1 = cx1;
     p->cy0 = cy0;
     p->cy1 = cy1;
 
     gnome_canvas_update_bbox (GNOME_CANVAS_ITEM (item), cx0, cy0, cx1, cy1);
+
+    if (klass->bbox_changed_hook)
+      klass->bbox_changed_hook (item, cx0, cy0, cx1, cy1);
+
+    guppi_canvas_item_request_update (item);
   }
 }
 
@@ -637,7 +628,7 @@ guppi_canvas_item_set_bbox_c (GuppiCanvasItem *item,
  *
  **/
 void
-guppi_canvas_item_get_bbox_c (GuppiCanvasItem * item,
+guppi_canvas_item_get_bbox_c (GuppiCanvasItem *item,
 			      gint *cx0, gint *cy0, gint *cx1, gint *cy1)
 {
   GuppiCanvasItemPrivate *p;
@@ -671,7 +662,7 @@ guppi_canvas_item_get_bbox_c (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_get_bbox_vp (GuppiCanvasItem * item,
+guppi_canvas_item_get_bbox_vp (GuppiCanvasItem *item,
 			       double *x0, double *y0, double *x1, double *y1)
 {
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -694,7 +685,7 @@ guppi_canvas_item_get_bbox_vp (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_get_bbox_pt (GuppiCanvasItem * item,
+guppi_canvas_item_get_bbox_pt (GuppiCanvasItem *item,
 			       double *x0, double *y0, double *x1, double *y1)
 {
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -717,7 +708,7 @@ guppi_canvas_item_get_bbox_pt (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_conv (GuppiCanvasItem * item,
+guppi_canvas_item_conv (GuppiCanvasItem *item,
 			double c_x, double c_y,
 			double *conv_x, double *conv_y)
 {
@@ -744,7 +735,7 @@ guppi_canvas_item_conv (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_unconv (GuppiCanvasItem * item,
+guppi_canvas_item_unconv (GuppiCanvasItem *item,
 			  double conv_x, double conv_y,
 			  double *c_x, double *c_y)
 {
@@ -771,7 +762,7 @@ guppi_canvas_item_unconv (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_vp2c (GuppiCanvasItem * item,
+guppi_canvas_item_vp2c (GuppiCanvasItem *item,
 			double vp_x, double vp_y, gint* c_x, gint *c_y)
 {
   double x = 0, y = 0;
@@ -800,7 +791,7 @@ guppi_canvas_item_vp2c (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_vp2c_d (GuppiCanvasItem * item,
+guppi_canvas_item_vp2c_d (GuppiCanvasItem *item,
 			  double vp_x, double vp_y, double *c_x, double *c_y)
 {
   GuppiElementView *view;
@@ -811,8 +802,8 @@ guppi_canvas_item_vp2c_d (GuppiCanvasItem * item,
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
 
   view = guppi_canvas_item_view (item);
-  vix = guppi_element_view_x_view_interval (view);
-  viy = guppi_element_view_y_view_interval (view);
+  vix = guppi_element_view_axis_view_interval (view, GUPPI_X_AXIS);
+  viy = guppi_element_view_axis_view_interval (view, GUPPI_Y_AXIS);
 
   tx = guppi_view_interval_conv (vix, vp_x);
   ty = guppi_view_interval_conv (viy, vp_y);
@@ -851,7 +842,7 @@ guppi_canvas_item_x_vp2c_d_bulk (GuppiCanvasItem *item,
   p = priv (item);
 
   view = guppi_canvas_item_view (item);
-  vix = guppi_element_view_x_view_interval (view);
+  vix = guppi_element_view_axis_view_interval (view, GUPPI_X_AXIS);
 
   guppi_view_interval_conv_bulk (vix, vp_x, c_x, N);
 
@@ -892,7 +883,7 @@ guppi_canvas_item_y_vp2c_d_bulk (GuppiCanvasItem *item,
   p = priv (item);
 
   view = guppi_canvas_item_view (item);
-  viy = guppi_element_view_y_view_interval (view);
+  viy = guppi_element_view_axis_view_interval (view, GUPPI_Y_AXIS);
 
   guppi_view_interval_conv_bulk (viy, vp_y, c_y, N);
 
@@ -916,7 +907,7 @@ guppi_canvas_item_y_vp2c_d_bulk (GuppiCanvasItem *item,
  *
  **/
 void
-guppi_canvas_item_vp2c_d_bulk (GuppiCanvasItem * item,
+guppi_canvas_item_vp2c_d_bulk (GuppiCanvasItem *item,
 			       const double *vp_x,
 			       const double *vp_y,
 			       double *c_x, double *c_y, gsize N)
@@ -937,8 +928,8 @@ guppi_canvas_item_vp2c_d_bulk (GuppiCanvasItem * item,
   p = priv (item);
 
   view = guppi_canvas_item_view (item);
-  vix = guppi_element_view_x_view_interval (view);
-  viy = guppi_element_view_y_view_interval (view);
+  vix = guppi_element_view_axis_view_interval (view, GUPPI_X_AXIS);
+  viy = guppi_element_view_axis_view_interval (view, GUPPI_Y_AXIS);
 
   guppi_view_interval_conv_bulk (vix, vp_x, c_x, N);
   guppi_view_interval_conv_bulk (viy, vp_y, c_y, N);
@@ -963,7 +954,7 @@ guppi_canvas_item_vp2c_d_bulk (GuppiCanvasItem * item,
  *
  **/
 void
-guppi_canvas_item_c2vp (GuppiCanvasItem * gci,
+guppi_canvas_item_c2vp (GuppiCanvasItem *gci,
 			double c_x, double c_y, double *vp_x, double *vp_y)
 {
   GuppiElementView *view;
@@ -977,12 +968,12 @@ guppi_canvas_item_c2vp (GuppiCanvasItem * gci,
   guppi_canvas_item_conv (gci, c_x, c_y, &tx, &ty);
 
   if (vp_x) {
-    GuppiViewInterval *vi = guppi_element_view_x_view_interval (view);
+    GuppiViewInterval *vi = guppi_element_view_axis_view_interval (view, GUPPI_X_AXIS);
     *vp_x = guppi_view_interval_unconv (vi, tx);
   }
 
   if (vp_y) {
-    GuppiViewInterval *vi = guppi_element_view_y_view_interval (view);
+    GuppiViewInterval *vi = guppi_element_view_axis_view_interval (view, GUPPI_Y_AXIS);
     *vp_y = guppi_view_interval_unconv (vi, 1 - ty);
   }
 
@@ -1000,8 +991,8 @@ guppi_canvas_item_c2vp (GuppiCanvasItem * gci,
  *
  **/
 void
-guppi_canvas_item_pt2c (GuppiCanvasItem * gci,
-			double pt_x, double pt_y, gint * c_x, gint * c_y)
+guppi_canvas_item_pt2c (GuppiCanvasItem *gci,
+			double pt_x, double pt_y, gint *c_x, gint *c_y)
 {
   double x = 0, y = 0;
 
@@ -1030,7 +1021,7 @@ guppi_canvas_item_pt2c (GuppiCanvasItem * gci,
  *
  **/
 void
-guppi_canvas_item_pt2c_d (GuppiCanvasItem * gci,
+guppi_canvas_item_pt2c_d (GuppiCanvasItem *gci,
 			  double pt_x, double pt_y, double *c_x, double *c_y)
 {
   GuppiGeometry *geom;
@@ -1135,7 +1126,7 @@ guppi_canvas_item_vpath_pt2c (GuppiCanvasItem *gci, ArtVpath *path)
  *
  **/
 void
-guppi_canvas_item_request_redraw_c (GuppiCanvasItem * gec,
+guppi_canvas_item_request_redraw_c (GuppiCanvasItem *gec,
 				    gint cx0, gint cy0, gint cx1, gint cy1)
 {
   GuppiCanvasItemPrivate *p;
@@ -1177,7 +1168,7 @@ guppi_canvas_item_request_redraw_c (GuppiCanvasItem * gec,
  *
  **/
 void
-guppi_canvas_item_request_redraw_vp (GuppiCanvasItem * gec,
+guppi_canvas_item_request_redraw_vp (GuppiCanvasItem *gec,
 				     double vx0, double vy0,
 				     double vx1, double vy1)
 {
@@ -1198,7 +1189,7 @@ guppi_canvas_item_request_redraw_vp (GuppiCanvasItem * gec,
  *
  **/
 void
-guppi_canvas_item_request_total_redraw (GuppiCanvasItem * item)
+guppi_canvas_item_request_total_redraw (GuppiCanvasItem *item)
 {
   gint cx0, cx1, cy0, cy1;
 
@@ -1259,7 +1250,7 @@ struct foreach_at {
 };
 
 static void
-foreach_at_fn (GuppiCanvasItem * item, gpointer ptr)
+foreach_at_fn (GuppiCanvasItem *item, gpointer ptr)
 {
   struct foreach_at *fa = (struct foreach_at *) ptr;
   GuppiGeometry *geom = guppi_canvas_item_geometry (item);
@@ -1283,7 +1274,7 @@ foreach_at_fn (GuppiCanvasItem * item, gpointer ptr)
  *
  **/
 void
-guppi_canvas_item_foreach_at (GuppiCanvasItem * item,
+guppi_canvas_item_foreach_at (GuppiCanvasItem *item,
 			      double pt_x, double pt_y,
 			      GuppiCanvasItemFunc fn, gpointer user_data)
 {
@@ -1307,7 +1298,7 @@ struct first_matching {
 };
 
 static void
-find_first_match (GuppiCanvasItem * item, gpointer ptr)
+find_first_match (GuppiCanvasItem *item, gpointer ptr)
 {
   struct first_matching *foo = (struct first_matching *) ptr;
 
@@ -1332,7 +1323,7 @@ find_first_match (GuppiCanvasItem * item, gpointer ptr)
  *
  **/
 GuppiCanvasItem *
-guppi_canvas_item_first_matching_at (GuppiCanvasItem * item,
+guppi_canvas_item_first_matching_at (GuppiCanvasItem *item,
 				     double pt_x, double pt_y,
 				     GuppiCanvasItemTest fn,
 				     gpointer user_data)
@@ -1344,14 +1335,14 @@ guppi_canvas_item_first_matching_at (GuppiCanvasItem * item,
 }
 
 static void
-item_list_fn (GuppiCanvasItem * item, gpointer ptr)
+item_list_fn (GuppiCanvasItem *item, gpointer ptr)
 {
   GList **lst = (GList **) ptr;
   *lst = g_list_append (*lst, item);
 }
 
 static GList *
-list_of_items_at (GuppiCanvasItem * item, double pt_x, double pt_y)
+list_of_items_at (GuppiCanvasItem *item, double pt_x, double pt_y)
 {
   GList *lst = NULL;
   guppi_canvas_item_foreach_at (item, pt_x, pt_y, item_list_fn, &lst);
@@ -1361,7 +1352,7 @@ list_of_items_at (GuppiCanvasItem * item, double pt_x, double pt_y)
 /***************************************************************************/
 
 static GuppiCanvasItem *
-find_item_supporting_tool (GuppiPlotTool * tool, GList * lst)
+find_item_supporting_tool (GuppiPlotTool *tool, GList *lst)
 {
   g_return_val_if_fail (tool != NULL && GUPPI_IS_PLOT_TOOL (tool), NULL);
   while (lst) {
@@ -1374,9 +1365,9 @@ find_item_supporting_tool (GuppiPlotTool * tool, GList * lst)
 }
 
 static gboolean
-find_tool (GuppiCanvasItem * item, double pt_x, double pt_y,
+find_tool (GuppiCanvasItem *item, double pt_x, double pt_y,
 	   gboolean is_button, guint button_or_key, guint state,
-	   GuppiCanvasItem ** op_item, GuppiPlotTool ** op_tool)
+	   GuppiCanvasItem **op_item, GuppiPlotTool **op_tool)
 {
 
   GList *item_list = list_of_items_at (item, pt_x, pt_y);
@@ -1447,7 +1438,7 @@ find_tool (GuppiCanvasItem * item, double pt_x, double pt_y,
 }
 
 static gboolean
-drop_candidate_test (GuppiCanvasItem * item, gpointer foo)
+drop_candidate_test (GuppiCanvasItem *item, gpointer foo)
 {
   GuppiCanvasItemClass *klass;
   klass = GUPPI_CANVAS_ITEM_CLASS (GTK_OBJECT (item)->klass);
@@ -1455,7 +1446,7 @@ drop_candidate_test (GuppiCanvasItem * item, gpointer foo)
 }
 
 GuppiCanvasItem *
-guppi_canvas_item_data_drop_candidate (GuppiCanvasItem * item,
+guppi_canvas_item_data_drop_candidate (GuppiCanvasItem *item,
 				       double pt_x, double pt_y)
 {
   return guppi_canvas_item_first_matching_at (item, pt_x, pt_y,
@@ -1463,7 +1454,7 @@ guppi_canvas_item_data_drop_candidate (GuppiCanvasItem * item,
 }
 
 gboolean
-guppi_canvas_item_data_drop (GuppiCanvasItem * item, GuppiData * data)
+guppi_canvas_item_data_drop (GuppiCanvasItem *item, GuppiData *data)
 {
   GuppiCanvasItemClass *klass;
 
@@ -1476,11 +1467,11 @@ guppi_canvas_item_data_drop (GuppiCanvasItem * item, GuppiData * data)
 }
 
 gboolean
-guppi_canvas_item_locate_button_tool (GuppiCanvasItem * item,
+guppi_canvas_item_locate_button_tool (GuppiCanvasItem *item,
 				      double pt_x, double pt_y,
 				      guint button, guint state,
-				      GuppiCanvasItem ** op_item,
-				      GuppiPlotTool ** op_tool)
+				      GuppiCanvasItem **op_item,
+				      GuppiPlotTool **op_tool)
 {
   g_return_val_if_fail (item && GUPPI_IS_CANVAS_ITEM (item), FALSE);
 
@@ -1488,11 +1479,11 @@ guppi_canvas_item_locate_button_tool (GuppiCanvasItem * item,
 }
 
 gboolean
-guppi_canvas_item_locate_key_tool (GuppiCanvasItem * item,
+guppi_canvas_item_locate_key_tool (GuppiCanvasItem *item,
 				   double pt_x, double pt_y,
 				   guint button, guint state,
-				   GuppiCanvasItem ** op_item,
-				   GuppiPlotTool ** op_tool)
+				   GuppiCanvasItem **op_item,
+				   GuppiPlotTool **op_tool)
 {
   g_return_val_if_fail (item && GUPPI_IS_CANVAS_ITEM (item), FALSE);
 
@@ -1500,7 +1491,7 @@ guppi_canvas_item_locate_key_tool (GuppiCanvasItem * item,
 }
 
 gboolean
-guppi_canvas_item_double_click (GuppiCanvasItem * item,
+guppi_canvas_item_double_click (GuppiCanvasItem *item,
 				double pt_x, double pt_y,
 				guint button, guint state)
 {
@@ -1521,8 +1512,8 @@ guppi_canvas_item_double_click (GuppiCanvasItem * item,
 }
 
 void
-guppi_canvas_item_set_local_toolkit (GuppiCanvasItem * item,
-				     GuppiPlotToolkit * tk)
+guppi_canvas_item_set_local_toolkit (GuppiCanvasItem *item,
+				     GuppiPlotToolkit *tk)
 {
   GuppiCanvasItemPrivate *p;
 
@@ -1535,7 +1526,7 @@ guppi_canvas_item_set_local_toolkit (GuppiCanvasItem * item,
 }
 
 void
-guppi_canvas_item_enable_local_toolkit (GuppiCanvasItem * item, gboolean x)
+guppi_canvas_item_enable_local_toolkit (GuppiCanvasItem *item, gboolean x)
 {
   GuppiCanvasItemPrivate *p;
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -1544,7 +1535,7 @@ guppi_canvas_item_enable_local_toolkit (GuppiCanvasItem * item, gboolean x)
 }
 
 void
-guppi_canvas_item_enable_class_toolkit (GuppiCanvasItem * item, gboolean x)
+guppi_canvas_item_enable_class_toolkit (GuppiCanvasItem *item, gboolean x)
 {
   GuppiCanvasItemPrivate *p;
   g_return_if_fail (item != NULL && GUPPI_IS_CANVAS_ITEM (item));
@@ -1554,14 +1545,14 @@ guppi_canvas_item_enable_class_toolkit (GuppiCanvasItem * item, gboolean x)
 
 /**************************************************************************/
 
-gboolean guppi_canvas_item_nonlocal_tools_disabled (GuppiCanvasItem * gci)
+gboolean guppi_canvas_item_nonlocal_tools_disabled (GuppiCanvasItem *gci)
 {
   g_return_val_if_fail (gci != NULL && GUPPI_IS_CANVAS_ITEM (gci), TRUE);
   return priv (gci)->disable_class_tools;
 }
 
 GuppiPlotTool *
-guppi_canvas_item_local_button_tool (GuppiCanvasItem * item,
+guppi_canvas_item_local_button_tool (GuppiCanvasItem *item,
 				     guint button, guint state)
 {
   GuppiCanvasItemPrivate *p;
@@ -1590,7 +1581,7 @@ guppi_canvas_item_local_button_tool (GuppiCanvasItem * item,
 }
 
 GuppiPlotTool *
-guppi_canvas_item_local_key_tool (GuppiCanvasItem * item,
+guppi_canvas_item_local_key_tool (GuppiCanvasItem *item,
 				  guint key, guint state)
 {
   GuppiCanvasItemPrivate *p;
@@ -1618,9 +1609,8 @@ guppi_canvas_item_local_key_tool (GuppiCanvasItem * item,
 }
 
 void
-guppi_canvas_item_foreach_class_toolkit (GuppiCanvasItem * item,
-					 void (*fn) (GuppiPlotToolkit *,
-						     gpointer),
+guppi_canvas_item_foreach_class_toolkit (GuppiCanvasItem *item,
+					 void (*fn) (GuppiPlotToolkit *, gpointer),
 					 gpointer user_data)
 {
   GuppiCanvasItemClass *klass;
@@ -1679,5 +1669,5 @@ guppi_canvas_item_class_set_item_class_toolkit (GuppiCanvasItemClass *klass,
 }
 
 
-/* $Id: guppi-canvas-item.c,v 1.35 2001/05/06 08:26:42 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.42 2001/11/16 16:58:56 trow Exp $ */
 
