@@ -1,10 +1,11 @@
 /* This is -*- C -*- */
-/* $Id: guppi-element-state.h,v 1.15 2001/05/03 23:03:04 trow Exp $ */
+/* $Id: guppi-element-state.h,v 1.24 2001/11/20 03:40:57 trow Exp $ */
 
 /*
  * guppi-element-state.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -29,12 +30,11 @@
 #define _INC_GUPPI_ELEMENT_STATE_H
 
 /* #include <gnome.h> */
-#include <guppi-unique-id.h>
-#include <guppi-config-item.h>
-#include <guppi-attributes.h>
-#include <guppi-xml.h>
-#include "guppi-shared-hash.h"
-#include <guppi-defs.h>
+#include "guppi-unique-id.h"
+#include "guppi-attribute-bag.h"
+#include "guppi-config-model.h"
+#include "guppi-xml.h"
+#include "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS
 
@@ -43,10 +43,11 @@ struct _GuppiElementView;
 
 typedef struct _GuppiElementState GuppiElementState;
 typedef struct _GuppiElementStateClass GuppiElementStateClass;
+struct _GuppiElementStatePrivate;
 
 struct _GuppiElementState {
   GtkObject parent;
-  gpointer opaque_internals;
+  struct _GuppiElementStatePrivate *priv;
 };
 
 struct _GuppiElementStateClass {
@@ -59,18 +60,16 @@ struct _GuppiElementStateClass {
 
   GtkType view_type;
   struct _GuppiElementView *(*make_view) (GuppiElementState *);
-  GuppiConfigItem *(*config_tree) (GuppiElementState *);
-  
+
+  GuppiConfigModel *(*make_config_model) (GuppiElementState *);
+
   /* XML input & output */
-  void       (*prepare_attributes) (GuppiAttributes *);
-  void       (*set_attributes)     (GuppiElementState *, GuppiAttributes *);
-  void       (*init_base_object)   (GuppiElementState *, GuppiAttributes *);
-  xmlNodePtr (*custom_xml_export)  (GuppiElementState *, GuppiXMLDocument *);
-  void       (*custom_xml_import)  (GuppiElementState *, GuppiXMLDocument *, xmlNodePtr);
+  void     (*xml_export)  (GuppiElementState *, GuppiXMLDocument *, xmlNodePtr root_node);
+  gboolean (*xml_import)  (GuppiElementState *, GuppiXMLDocument *, xmlNodePtr);
 
   /* Signals */
   void (*changed)      (GuppiElementState *);
-  void (*changed_size) (GuppiElementState *);
+  void (*changed_size) (GuppiElementState *, double width, double height);
 };
 
 #define GUPPI_TYPE_ELEMENT_STATE (guppi_element_state_get_type())
@@ -83,42 +82,27 @@ struct _GuppiElementStateClass {
 
 GtkType guppi_element_state_get_type (void);
 
-GuppiElementState *guppi_element_state_new (const gchar * type,
-					    const gchar * first_arg_name,
-					    ...);
-GuppiElementState *guppi_element_state_newv (const gchar * type, guint nargs,
-					     GtkArg * args);
+GuppiElementState *guppi_element_state_new (const gchar *type, ...);
 
-guppi_uniq_t guppi_element_state_unique_id (GuppiElementState *);
+guppi_uniq_t       guppi_element_state_unique_id     (GuppiElementState *);
+GuppiAttributeBag *guppi_element_state_attribute_bag (GuppiElementState *);
 
-const gchar *guppi_element_state_label (GuppiElementState *);
-void guppi_element_state_set_label (GuppiElementState *, const gchar *);
+const gchar *guppi_element_state_get_label (GuppiElementState *);
+void         guppi_element_state_set_label (GuppiElementState *, const gchar *label);
+
+gboolean guppi_element_state_get (GuppiElementState *, ...);
+gboolean guppi_element_state_set (GuppiElementState *, ...);
 
 struct _GuppiElementView *guppi_element_state_make_view (GuppiElementState *);
 
+void         guppi_element_state_changed (GuppiElementState *);
+void         guppi_element_state_changed_delayed (GuppiElementState *);
+void         guppi_element_state_flush_changes (GuppiElementState *);
+const gchar *guppi_element_state_get_changed_attribute (GuppiElementState *);
 
-void guppi_element_state_add_shared (GuppiElementState *,
-				     const gchar * key, GuppiShared *);
-void guppi_element_state_set_shared (GuppiElementState *,
-				     const gchar * key, gpointer obj_or_null);
-GtkObject *guppi_element_state_get_shared (GuppiElementState *,
-					   const gchar * key);
-
-
-void guppi_element_state_connect (GuppiElementState * s1, const gchar * key1,
-				  GuppiElementState * s2, const gchar * key2);
-
-
-void guppi_element_state_changed (GuppiElementState *);
-void guppi_element_state_changed_delayed (GuppiElementState *);
-void guppi_element_state_changed_size (GuppiElementState *);
-
-void guppi_element_state_connect_to_object (GuppiElementState *,
-					    const gchar * signal_name,
-					    GtkObject *);
-void guppi_element_state_disconnect_from_object (GuppiElementState *,
-						 GtkObject *);
+void guppi_element_state_changed_size (GuppiElementState *, double width, double height);
 
+GuppiConfigModel *guppi_element_state_make_config_model (GuppiElementState *);
 
 xmlNodePtr         guppi_element_state_export_xml (GuppiElementState *, GuppiXMLDocument *);
 GuppiElementState *guppi_element_state_import_xml (GuppiXMLDocument *, xmlNodePtr);
@@ -129,4 +113,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ELEMENT_STATE_H */
 
-/* $Id: guppi-element-state.h,v 1.15 2001/05/03 23:03:04 trow Exp $ */
+/* $Id: guppi-element-state.h,v 1.24 2001/11/20 03:40:57 trow Exp $ */
