@@ -1,11 +1,12 @@
 
 /* This is -*- C -*- */
-/* $Id: guppi-element-view.h,v 1.24 2001/05/03 23:03:04 trow Exp $ */
+/* $Id: guppi-element-view.h,v 1.35 2001/11/20 03:40:57 trow Exp $ */
 
 /*
  * guppi-element-view.h
  *
  * Copyright (C) 2000 EMC Capital Management, Inc.
+ * Copyright (C) 2001 The Free Software Foundation
  *
  * Developed by Jon Trowbridge <trow@gnu.org> and
  * Havoc Pennington <hp@pobox.com>.
@@ -33,13 +34,15 @@
 #include <libgnomeprint/gnome-print.h>
 #include <libgnomeui/gnome-canvas.h>
 
-#include <guppi-config-item.h>
+#include "guppi-enums.h"
 #include "guppi-element-state.h"
 #include "guppi-geometry.h"
 #include "guppi-view-interval.h"
 #include "guppi-axis-markers.h"
 
-#include <guppi-defs.h>
+#include "guppi-defs.h"
+
+#define DEPRECATED_GUPPI_ELEMENT_VIEW 0
 
 BEGIN_GUPPI_DECLS 
 
@@ -49,54 +52,59 @@ struct _GuppiElementPrint;
 
 typedef struct _GuppiElementView GuppiElementView;
 typedef struct _GuppiElementViewClass GuppiElementViewClass;
+struct _GuppiElementViewPrivate;
 
 struct _GuppiElementView {
   GtkObject parent;
-  gpointer opaque_internals;
+  struct _GuppiElementViewPrivate *priv;
 };
 
 struct _GuppiElementViewClass {
   GtkObjectClass parent_class;
 
+  const gchar *plug_in_code;
+
   /* VTable */
   GtkType canvas_item_type;
   struct _GuppiCanvasItem *(*make_canvas_item) (GuppiElementView *,
 						GnomeCanvas *,
 						GnomeCanvasGroup *);
+  void (*item_post_creation_init) (GuppiElementView *view, struct _GuppiCanvasItem *item);
 
   GtkType print_type;
   struct _GuppiElementPrint *(*make_print) (GuppiElementView *,
 					    GnomePrintContext *);
 
-  void (*state_changed) (GuppiElementView *);
-  void (*x_interval_changed) (GuppiElementView *);
-  void (*y_interval_changed) (GuppiElementView *);
-
-  void (*get_style_bounds) (GuppiElementView *, gint *, gint *);
-  struct _GuppiStyle *(*get_style) (GuppiElementView *, gint);
-
   /* Init function called after view is constructed and has parent state
      attached. */
   void (*view_init) (GuppiElementView *);
 
-  void (*update_x_axis_markers) (GuppiElementView *, GuppiAxisMarkers *,
-				 double x0, double x1);
-  void (*update_y_axis_markers) (GuppiElementView *, GuppiAxisMarkers *,
-				 double y0, double y1);
+  void (*update_axis_markers) (GuppiElementView *, guppi_axis_t, GuppiAxisMarkers *, double x0, double x1);
 
-  gboolean (*preferred_x_range) (GuppiElementView *, double *, double *);
-  gboolean (*preferred_y_range) (GuppiElementView *, double *, double *);
-
-  GuppiConfigItem *(*config_tree) (GuppiElementView *);
-  GuppiConfigItem *(*assemble_config_tree) (GuppiElementView *,
-					    GuppiConfigItem * view_tree,
-					    GuppiConfigItem * state_tree);
+  gboolean (*preferred_range) (GuppiElementView *, guppi_axis_t, double *, double *);
 
   void (*print) (GuppiElementView *, GnomePrintContext *);
 
+  /* Freeze/thaw */
+
+  void (*freeze)       (GuppiElementView *);
+  void (*thaw)         (GuppiElementView *);
+  void (*fully_thawed) (GuppiElementView *);
+
+  gboolean (*find) (GuppiElementView *view, const gchar *label, 
+		    GuppiElementState **stateptr, GuppiElementView **viewptr);
+
+  GuppiConfigModel *(*make_config_model) (GuppiElementView *);
+
+  /* XML input & output */
+  void     (*xml_export)  (GuppiElementView *, GuppiXMLDocument *, xmlNodePtr root_node);
+  gboolean (*xml_import)  (GuppiElementView *, GuppiXMLDocument *, xmlNodePtr);
+
   /* Signals */
-  void (*changed) (GuppiElementView *);
-  void (*changed_size) (GuppiElementView *);
+  void (*changed)           (GuppiElementView *);
+  void (*changed_state)     (GuppiElementView *); /* the underlying state object emitted 'changed' */
+  void (*changed_size)      (GuppiElementView *, double w, double h);
+  void (*changed_position)  (GuppiElementView *);
   void (*changed_structure) (GuppiElementView *);
 };
 
@@ -110,21 +118,44 @@ struct _GuppiElementViewClass {
 
 GtkType guppi_element_view_get_type (void);
 
+GuppiElementView *guppi_element_view_new (GuppiElementState *, ...);
+
 GuppiElementState *guppi_element_view_state (GuppiElementView *);
 GuppiGeometry *guppi_element_view_geometry (GuppiElementView *);
 
 guppi_uniq_t guppi_element_view_unique_id (GuppiElementView *);
 
-GuppiViewInterval *guppi_element_view_x_view_interval (GuppiElementView *);
-GuppiViewInterval *guppi_element_view_y_view_interval (GuppiElementView *);
+const gchar *guppi_element_view_get_label (GuppiElementView *);
+void         guppi_element_view_set_label (GuppiElementView *, const gchar *);
 
-gint guppi_element_view_x_axis_marker_type (GuppiElementView *);
-gint guppi_element_view_y_axis_marker_type (GuppiElementView *);
-void guppi_element_view_set_x_axis_marker_type (GuppiElementView *, gint code);
-void guppi_element_view_set_y_axis_marker_type (GuppiElementView *, gint code);
+gboolean guppi_element_view_get (GuppiElementView *, ...);
+gboolean guppi_element_view_set (GuppiElementView *, ...);
+
+GuppiElementState *guppi_element_view_find_state (GuppiElementView *, const gchar *label);
+GuppiElementView  *guppi_element_view_find_view  (GuppiElementView *, const gchar *label);
+
+
+/* View Intervals */
+
+GuppiViewInterval *guppi_element_view_axis_view_interval (GuppiElementView *, guppi_axis_t);
+void               guppi_element_view_connect_view_intervals (GuppiElementView *view1, guppi_axis_t axis1,
+							      GuppiElementView *view2, guppi_axis_t axis2);
+
+void guppi_element_view_set_preferred_view (GuppiElementView *, guppi_axis_t);
+void guppi_element_view_set_preferred_view_all (GuppiElementView *);
+void guppi_element_view_force_preferred_view (GuppiElementView *, guppi_axis_t, gboolean);
+
+
+/* Axis Markers */
+
+void              guppi_element_view_add_axis_markers     (GuppiElementView *, guppi_axis_t);
+gint              guppi_element_view_axis_marker_type     (GuppiElementView *, guppi_axis_t);
+void              guppi_element_view_set_axis_marker_type (GuppiElementView *, guppi_axis_t, gint code);
+GuppiAxisMarkers *guppi_element_view_axis_markers         (GuppiElementView *, guppi_axis_t);
+
+void              guppi_element_view_connect_axis_markers (GuppiElementView *view1, guppi_axis_t axis1,
+							   GuppiElementView *view2, guppi_axis_t axis2);
 
-GuppiAxisMarkers *guppi_element_view_x_axis_markers (GuppiElementView *);
-GuppiAxisMarkers *guppi_element_view_y_axis_markers (GuppiElementView *);
 
 void guppi_element_view_set_state (GuppiElementView *, GuppiElementState *);
 
@@ -136,10 +167,10 @@ void guppi_element_view_get_bbox_pt (GuppiElementView *,
 				     double *x1, double *y1);
 
 #define guppi_element_view_valid_x_vp(gev, x) \
-(guppi_view_interval_valid(guppi_element_view_x_view_interval(gev), (x)))
+(guppi_view_interval_valid(guppi_element_view_axis_view_interval((gev), GUPPI_X_AXIS), (x)))
 
 #define guppi_element_view_valid_y_vp(gev, y) \
-(guppi_view_interval_valid(guppi_element_view_y_view_interval(gev), (y)))
+(guppi_view_interval_valid(guppi_element_view_axis_view_interval((gev), GUPPI_Y_AXIS), (y)))
 
 #define guppi_element_view_valid_vp(gev, x, y) \
 (guppi_element_view_valid_x_vp((gev), (x)) && \
@@ -150,66 +181,46 @@ void guppi_element_view_vp2pt (GuppiElementView *,
 void guppi_element_view_pt2vp (GuppiElementView *,
 			       double, double, double *, double *);
 
-struct _GuppiCanvasItem *guppi_element_view_make_canvas_item (GuppiElementView
-							      *,
+struct _GuppiCanvasItem *guppi_element_view_make_canvas_item (GuppiElementView *,
 							      GnomeCanvas *,
-							      GnomeCanvasGroup
-							      *);
+							      GnomeCanvasGroup *);
 struct _GuppiElementPrint *guppi_element_view_make_print (GuppiElementView *,
-							  GnomePrintContext
-							  *);
-
-void guppi_element_view_change_along_with_shared_object (GuppiElementView *,
-							 GuppiShared *);
-
-void guppi_element_view_connect (GuppiElementView * v1, const gchar * key1,
-				 GuppiElementView * v2, const gchar * key2);
-
-void guppi_element_view_set_preferred_x_view (GuppiElementView *);
-void guppi_element_view_set_preferred_y_view (GuppiElementView *);
-void guppi_element_view_set_preferred_view (GuppiElementView *);
-
-void guppi_element_view_force_preferred_x_view (GuppiElementView *, gboolean);
-void guppi_element_view_force_preferred_y_view (GuppiElementView *, gboolean);
-void guppi_element_view_force_preferred_view (GuppiElementView *, gboolean);
+							  GnomePrintContext *);
 
 gboolean guppi_element_view_visible (GuppiElementView *);
 void guppi_element_view_show (GuppiElementView *);
 void guppi_element_view_hide (GuppiElementView *);
 void guppi_element_view_set_visibility (GuppiElementView *, gboolean);
 
-void guppi_element_view_style_bounds (GuppiElementView *, gint *, gint *);
-gboolean guppi_element_view_style_in_bounds (GuppiElementView *, gint);
-struct _GuppiStyle *guppi_element_view_style (GuppiElementView *, gint);
-
 gboolean guppi_element_view_tools_are_blocked (GuppiElementView *);
 void guppi_element_view_set_tool_blocking (GuppiElementView *, gboolean);
 
-GuppiConfigItem *guppi_element_view_config_tree (GuppiElementView *);
-
 void guppi_element_view_print (GuppiElementView *, GnomePrintContext *);
 void guppi_element_view_print_to_bbox (GuppiElementView *,
 				       GnomePrintContext *,
 				       double x0, double y0,
 				       double x1, double y1);
-void guppi_element_view_print_ps_to_file (GuppiElementView *,
-					  const gchar * filename);
+void guppi_element_view_print_ps_to_file (GuppiElementView *, const gchar *filename);
 
 void guppi_element_view_changed (GuppiElementView *);
 void guppi_element_view_changed_delayed (GuppiElementView *);
 void guppi_element_view_flush_changes (GuppiElementView *);
 
-void guppi_element_view_changed_size (GuppiElementView *);
-
-void guppi_element_view_freeze (GuppiElementView *);
-void guppi_element_view_thaw (GuppiElementView *);
-
+void guppi_element_view_changed_size (GuppiElementView *, double width, double height);
 void guppi_element_view_changed_structure (GuppiElementView *);
-void guppi_element_view_changed_structure_delayed (GuppiElementView *);
 
+gboolean guppi_element_view_frozen (GuppiElementView *);
+void     guppi_element_view_freeze (GuppiElementView *);
+void     guppi_element_view_thaw   (GuppiElementView *);
+
+GuppiConfigModel *guppi_element_view_make_config_model (GuppiElementView *view);
+
+xmlNodePtr        guppi_element_view_export_xml (GuppiElementView *, GuppiXMLDocument *);
+GuppiElementView *guppi_element_view_import_xml (GuppiXMLDocument *, xmlNodePtr);
+void              guppi_element_view_spew_xml   (GuppiElementView *);
 
 END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ELEMENT_VIEW_H */
 
-/* $Id: guppi-element-view.h,v 1.24 2001/05/03 23:03:04 trow Exp $ */
+/* $Id: guppi-element-view.h,v 1.35 2001/11/20 03:40:57 trow Exp $ */
