@@ -1,6 +1,6 @@
 /* This is -*- C -*- */
 /* vim: set sw=2: */
-/* $Id: guppi-layout-engine.c,v 1.11 2001/10/08 04:22:14 trow Exp $ */
+/* $Id: guppi-layout-engine.c,v 1.13 2001/11/20 05:16:42 trow Exp $ */
 
 /*
  * guppi-layout-engine.c
@@ -694,17 +694,17 @@ guppi_layout_engine_remove_rule (GuppiLayoutEngine *engine, GuppiLayoutRule *rul
     return;
 
   engine->priv->rules = g_list_remove_link (engine->priv->rules, node);
-  guppi_layout_rule_unref (node->data);
   g_list_free_1 (node);
 
   guppi_layout_rule_foreach (rule, remove_rule_foreach_constraint_fn, engine);
+  guppi_layout_rule_unref (rule);
 
   schedule_layout (engine);
   gtk_signal_emit (GTK_OBJECT (engine), guppi_layout_engine_signals[CHANGED]);
 }
 
 void
-guppi_layout_engine_remove_geometry (GuppiLayoutEngine *engine, GuppiGeometry *geom)
+guppi_layout_engine_remove_geometry_rules (GuppiLayoutEngine *engine, GuppiGeometry *geom)
 {
   GList *rules_copy, *iter;
 
@@ -713,6 +713,8 @@ guppi_layout_engine_remove_geometry (GuppiLayoutEngine *engine, GuppiGeometry *g
 
   g_assert (engine->priv->reentry_count == 0);
 
+  /* Find and remove any rules that mention geom */
+
   rules_copy = g_list_copy (engine->priv->rules);
 
   for (iter = rules_copy; iter != NULL; iter = g_list_next (iter)) {
@@ -723,7 +725,27 @@ guppi_layout_engine_remove_geometry (GuppiLayoutEngine *engine, GuppiGeometry *g
 
   g_list_free (rules_copy);
 
-  g_assert (find_geometry_info (engine, geom) == NULL);
+  schedule_layout (engine);
+  gtk_signal_emit (GTK_OBJECT (engine), guppi_layout_engine_signals[CHANGED]);
+}
+
+void
+guppi_layout_engine_remove_geometry (GuppiLayoutEngine *engine, GuppiGeometry *geom)
+{
+  GeometryInfo *info;
+
+  g_return_if_fail (engine && GUPPI_IS_LAYOUT_ENGINE (engine));
+  g_return_if_fail (geom && GUPPI_IS_GEOMETRY (geom));
+
+  g_assert (engine->priv->reentry_count == 0);
+
+  guppi_layout_engine_remove_geometry_rules (engine, geom);
+
+  /* Remove our main reference */
+  remove_geometry (engine,geom);
+
+  info = find_geometry_info (engine, geom);
+  g_assert (info == NULL);
 
   schedule_layout (engine);
   gtk_signal_emit (GTK_OBJECT (engine), guppi_layout_engine_signals[CHANGED]);
