@@ -1,4 +1,4 @@
-/* $Id: guppi-enums.h,v 1.12 2001/09/03 02:45:13 trow Exp $ */
+/* $Id: guppi-enums.h,v 1.13 2001/11/19 05:40:52 trow Exp $ */
 
 /*
  * guppi-enums.h
@@ -30,7 +30,7 @@
 
 /* #include <gtk/gtk.h> */
 #include <glib.h>
-#include <guppi-defs.h>
+#include  "guppi-defs.h"
 
 BEGIN_GUPPI_DECLS 
 
@@ -97,4 +97,4 @@ END_GUPPI_DECLS
 
 #endif /* _INC_GUPPI_ENUMS_H */
 
-/* $Id: guppi-enums.h,v 1.12 2001/09/03 02:45:13 trow Exp $ */
+/* $Id: guppi-enums.h,v 1.13 2001/11/19 05:40:52 trow Exp $ */
