@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plug-in-spec.c,v 1.15 2001/05/06 08:26:46 trow Exp $ */
+/* $Id: guppi-plug-in-spec.c,v 1.17 2001/08/26 03:04:33 trow Exp $ */
 
 /*
  * guppi-plug-in-spec.c
@@ -26,6 +26,8 @@
  */
 
 #include <config.h>
+#include "guppi-plug-in-spec.h"
+
 #include <stdio.h>
 #include <dirent.h>
 #include <ctype.h>
@@ -35,9 +37,8 @@
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-i18n.h>
-
 #include <guppi-useful.h>
-#include "guppi-plug-in-spec.h"
+
 
 static GtkObjectClass *parent_class = NULL;
 
@@ -386,29 +387,29 @@ validate_spec (GuppiPlugInSpec * spec)
   gchar *s;
 
   if (spec->code == NULL) {
-    g_warning ("No code! (%s)", spec->path);
+    g_print ("No code! (%s)\n", spec->path);
     return FALSE;
   }
 
   if (spec->type == NULL) {
-    g_warning ("No type! (%s)", spec->path);
+    g_print ("No type! (%s)\n", spec->path);
     return FALSE;
   }
 
   if (spec->name == NULL) {
-    g_warning ("No name! (%s)", spec->path);
+    g_print ("No name! (%s)\n", spec->path);
     return FALSE;
   }
 
   /* Make sure the plug-in file exists. */
   if (spec->so_filename == NULL) {
-    g_warning ("No plug-in specified (%s)", spec->path);
+    g_print ("No plug-in specified (%s)\n", spec->path);
     return FALSE;
   }
 
   s = plug_in_filename (spec->path, spec->so_filename);
   if (s == NULL) {
-    g_warning ("Plug-in %s not found", spec->so_filename);
+    g_print ("Plug-in %s not found\n", spec->so_filename);
     return FALSE;
   }
   guppi_free (s);
@@ -496,7 +497,7 @@ guppi_plug_in_spec_plug_in (GuppiPlugInSpec * spec)
     path = plug_in_filename (spec->path, spec->so_filename);
 
     if (path == NULL) {
-      g_warning ("Plug-in %s (%s) not found!", spec->so_filename, spec->code);
+      g_print ("Plug-in %s (%s) not found.\n", spec->so_filename, spec->code);
       return NULL;
     }
 
@@ -940,4 +941,4 @@ guppi_plug_in_spec_shutdown (gpointer ignored)
 }
 
 
-/* $Id: guppi-plug-in-spec.c,v 1.15 2001/05/06 08:26:46 trow Exp $ */
+/* $Id: guppi-plug-in-spec.c,v 1.17 2001/08/26 03:04:33 trow Exp $ */
